@@ -4,15 +4,15 @@ package RRDTool::Creator ;
 # 
 #           Jacquelin Charbonnel - CNRS/LAREMA
 #  
-#   $Id: Creator.pm 410 2008-03-11 21:45:09Z jaclin $
+#   $Id: Creator.pm 170 2007-04-24 20:15:02Z jaclin $
 #   
 # ----
 #  
 #   A generic abstract creator for round robin databases (RRD)
 # 
 # ----
-#   $LastChangedDate: 2008-03-11 22:45:09 +0100 (Tue, 11 Mar 2008) $ 
-#   $LastChangedRevision: 410 $
+#   $LastChangedDate: 2007-04-24 22:15:02 +0200 (Tue, 24 Apr 2007) $ 
+#   $LastChangedRevision: 170 $
 #   $LastChangedBy: jaclin $
 #   $URL: https://svn.math.cnrs.fr/jaclin/src/pm/RRDTool-Creator/Creator.pm $
 #  
@@ -27,7 +27,7 @@ use RRDTool::OO ;
 use strict ;
 use warnings ;
 
-our $VERSION = "0.10" ; # $LastChangedRevision: 410 $
+our $VERSION = "0.2" ; # $LastChangedRevision: 170 $
 $Carp::CarpLevel = 1;
 
 my $InSeconds = {
@@ -36,9 +36,9 @@ my $InSeconds = {
     , "h" => 60*60
     , "d" => 60*60*24
     , "w" => 60*60*24*7
-    , "m" => 60*60*24*30        # supposed 30 days
-    , "q" => 60*60*24*30*3      # 3 months
-    , "y" => 60*60*24*30*12     # 12 months
+    , "m" => 60*60*24*30
+    , "q" => 60*60*24*30*3
+    , "y" => 60*60*24*365
     } ;
 
 sub _getkey
@@ -57,7 +57,7 @@ sub _inSeconds
   my($duration,$allowed) = @_ ;
   $Carp::CarpLevel = 2 ;
   
-  my ($num,$unit) = $duration=~/^\s*(\d+)\s*([a-zA-Z]+)\s*$/  or return undef ;
+  my ($num,$unit) = $duration=~/^\s*(\d)+\s*([a-zA-Z]+)$/  or return undef ;
   my %allowed = map { $_ => 1 } @$allowed ;
   
   croak "unit '$unit' not allowed" unless exists $allowed{lc($unit)} ;
@@ -67,7 +67,7 @@ sub _inSeconds
 }
 
 #--
-sub _new
+sub new
 {
   my($type,$units,%h) = @_ ;
 
@@ -90,7 +90,7 @@ sub _new
 }
 
 #-------------------------------
-sub _set_filename
+sub set_filename
 {
   my($this,$filename) = @_ ;
   $this->{"filename"} = $filename ;
@@ -205,12 +205,12 @@ push(@arg,("archive",
 
   for my $cpoint (@{$this->{"RRA"}})
   {
-      for my $cfunc (@{$this->{"CF"}})
+      for my $cfunc (@{$this->{"cf"}})
       {
         push(@arg,("archive", 
             { 
                 "cfunc" => $cfunc
-                , "cpoints" => $InSeconds->{substr($cpoint->{"duration"},0,1)}/($this->{"step"}*$this->{"rows"})
+                , "cpoints" => $cpoint
                 , "rows" => $this->{"rows"}
             }
             )
@@ -242,27 +242,27 @@ sub create
 __END__
 =head1 NAME
 
-C<RRDTool::Creator> - Creators for round robin databases (RRD)
+RRDTool::Creator - Creators for round robin databases (RRD)
 
 =head1 COMPONENTS
 
-C<RRDTool::Creator> - A generic abstract creator for round robin databases (RRD)
+RRDTool::Creator - A generic abstract creator for round robin databases (RRD)
 
-C<RRDTool::Creator::HourPDP> - creates a RRD with a default archive of primary points for an hour
+RRDTool::Creator::HourPDP - creates a RRD with a default archive of primary points for an hour
 
-C<RRDTool::Creator::DayPDP> - creates a RRD with a default archive of primary points for a day
+RRDTool::Creator::DayPDP - creates a RRD with a default archive of primary points for a day
 
-C<RRDTool::Creator::WeekPDP> - creates a RRD with a default archive of primary points for a week
+RRDTool::Creator::WeekPDP - creates a RRD with a default archive of primary points for a week
 
-C<RRDTool::Creator::MonthPDP> - creates a RRD with a default archive of primary points for a month
+RRDTool::Creator::MonthPDP - creates a RRD with a default archive of primary points for a month
 
-C<RRDTool::Creator::QuarterPDP> - creates a RRD with a default archive of primary points for a quarter
+RRDTool::Creator::QuarterPDP - creates a RRD with a default archive of primary points for a quarter
 
-C<RRDTool::Creator::YearPDP> - creates a RRD with a default archive of primary points for a year
+RRDTool::Creator::YearPDP - creates a RRD with a default archive of primary points for a year
 
 =head1 SYNOPSIS
 
-  use RRDTool::Creator::DayPDP ; 
+  use RRDTool::Creator::DayPDP ;
 
   # make a creator
   $creator = new RRDTool::Creator::DayPDP(-step => "30mn") ; 
@@ -293,98 +293,85 @@ C<RRDTool::Creator::YearPDP> - creates a RRD with a default archive of primary p
     
 =head1 DESCRIPTION
 
-The C<RRDTool::Creator> objects are specific creators for different kind of RRD files. 
-They are based on the Round Robin Database Tool (L<http://www.rrdtool.org>) and on the Perl module L<RRDTool::OO>.
+The RRDTool::Creator objects are specific creators for different kind of RRD files. 
+They are based on the Round Robin Database Tool (L<http://www.rrdtool.org>) and on the Perl Module RRDTool::OO.
 
 =head1 NOTES
 
-C<RRDTool::Creator> tries to be compatible with both the official RRDTool documentation 
-and the C<RRDTool::OO> module. 
+RRDTool::Creator tries to be compatible with both the official RRDTool documentation 
+and the RRDTool::OO module. 
 It is why some functions and some arguments have two possible names
-(in this case, the main name is conform to the official documentation and the auxiliary one is for compatibility with the C<RRDTool::OO> module).
+(in this case, the main name is conform to the official documentation and the auxiliary one is for compatibility with the RRDTool::OO module).
 
 =cut
 
 =head1 COMMON METHODS
 
-=head2 add_data_source
-
-See add_DS
-
 =head2 add_DS (auxiliary name: add_data_source)
 
 Add a data source in the RRD specifications.
 Its arguments are :
 
-=over 4
+=over 2
 
-=item B<ds_name> (auxiliary name: B<name>)
+=item ds_name (auxiliary name: name)
 
-(I<mandatory>) The name of the data source.
+(mandatory) the name of the data source.
 
-=item B<DST> (auxiliary name: B<type>)
+=item DST (auxiliary name: type)
 
-(I<mandatory>) The data source type : C<GAUGE>, C<COUNTER>, C<DERIVE> or C<ABSOLUTE> (see L<http://www.rrdtool.org>).
+(mandatory) the data source type : GAUGE, COUNTER, DERIVE or ABSOLUTE (see L<http://www.rrdtool.org>).
 
-=item B<heartbeat>
+=item heartbeat 
 
-(I<optionnal>) The maximum number of seconds that may pass between two updates of this data source before the value of the data source is assumed to be *UNKNOWN*.
+(optionnal) maximum number of seconds that may pass between two updates of this data source before the value of the data source is assumed to be *UNKNOWN*.
 Default is 2*step.
 
-=item B<min>
+=item min
 
-(I<optionnal>) The expected minimum value for data supplied by a data source. 
+(optionnal) Expected minimun value for data supplied by a data source. 
 Any value outside the defined range will be regarded as *UNKNOWN*. 
 Default is "U" for unknown.
 
-=item B<max>
+=item max
 
-(I<optionnal>) The expected maximum value for data supplied by a data source. 
+(optionnal) Expected maximun value for data supplied by a data source. 
 Any value outside the defined range will be regarded as *UNKNOWN*. 
 Default is "U" for unknown.
 
-    $creator->add_DS(
-                -ds_name => "cpu"
-                , -DST => "GAUGE"
-                , -min => 0
-                , -max => 100
-                ) ;
-
 =back
 
 =head2 add_compute_DS (not yet implemented)
 
-Add a data source with computed primary data points (it is a DS with DST equal to C<COMPUTE>) in the RRD specifications.
+Add a data source with computed primary data points (it is a DS with DST equal to COMPUTE) in the RRD specifications.
 Its arguments are :
 
-=over 4
+=over 2
 
-=item B<ds_name> (auxiliary name: B<name>)
+=item ds_name (auxiliary name: name)
 
-(I<mandatory>) The name of the data source.
+(mandatory) the name of the data source.
 
-=item B<rpn_expression>
+=item rpn_expression
 
-(I<mandatory>) RPN expression that defines formula to compute PDP of this DS.
+(mandatory) RPN expression that defines formula to compute PDP of this DS.
 
 =back
 
-=head2 B<add_RRA> (auxiliary name: B<add_archive>)
+=head2 add_RRA (auxiliary name: add_archive)
 
 Add a round robin archive in the RRD specifications.
 
-=over 4
+=over 2
 
-=item B<duration>
+=item duration
 
-(I<mandatory>) The duration of the archive.
+(mandatory) The duration of the archive.
 Possible values are : "day", "week", "month", "quarter" and "year".
 
-=item B<xff>
+=item xff
 
-(I<optionnal>) The xfiles factor (see <http://www.rrdtool.org>)
-
-    $creator->add_RRA(-duration => "day") ;
+(optionnal) The xfiles factor (see <http://www.rrdtool.org>)
 
 =back
 
@@ -392,56 +379,42 @@ Possible values are : "day", "week", "month", "quarter" and "year".
 
 Add some global attributes in the RRD specifications.
 
-=over 4
+=over 2
 
-=item B<CF> (auxiliary name: B<cfunc>)
+=item CF (auxiliary name: cfunc)
 
-Add a consolidation function (C<AVERAGE>, C<MIN>, C<MAX>, C<LAST>... - see <http://www.rrdtool.org>), 
+Add a consolidation function (AVERAGE, MIN, MAX, LAST... - see <http://www.rrdtool.org>), 
 for each RRA (except the default RRA) in the RRD specifications.
 
-    $creator->add(-CF => "AVERAGE") ;
-
 =back
 
-=head2 B<compile>
+=head2 compile
 
-Compute the argument for the function C<create> of the underlaying RRDTool::OO object.
-Useful for debugging, this function also allows to customize the command passed to rrdtool.
-Return this argument (a list). 
+Compute the argument for the function 'create' of the underlaying RRDTool::OO object.
+Return this argument.
 
-    @args = $creator->compile() ;
-
-=head2 B<create>
+=head2 create
 
 Create the RRD on the disk.
 
-=over 4
+=over 2
 
-=item B<filename> (auxiliary name: B<file>)
+=item filename (auxiliary name: file)
 
-(I<mandatory>) The name of the file to create.
+(mandatory) The name of the file to create.
 
-=item B<OO_create_arg>
+=item OO_create_arg
 
-(I<optionnal>) The argument passed to the function create of the underlaying RRDTool::OO object
-(this is the value returned by the previous function C<compile>).
-In normal case, this argument isn't provided, and its value is compiled from the current stored data.
-
-    $creator->create(-filename => "/tmp/15s.rrd") ;
-
-which can be break up to :
-
-    @args = $creator->compile() ;
-    # possible manual modification on @args here...
-    $creator->create(-filename => "/tmp/15s.rrd", OO_create_arg => \@args) ;
+(optionnal) The argument passed to the function create of the underlaying RRDTool::OO object.
+If this argument isn't provided, its value is compiled from the current stored data.
 
 =back
 
 =head1 SUB-OBJECTS
 
-Each sub-objects of C<RRDTool::Creator> creates a RRD with one default archive (RRA) made of primary data points (PDP).
+Each sub-objects of RRDTool::Creator creates a RRD with one default archive (RRA) made of primary data points (PDP).
 More RAA can then be added.
-The constructor neads an argument named C<step> which is the period of acquisition. The time unit of the step depends of the sub-object.
+The constructor neads an argument named 'step' which is the period of acquisition. The time unit of the step depends of the sub-object.
 
 =head2 RRDTool::Creator::HourPDP
 
@@ -581,11 +554,6 @@ with the aim of graphing max values weekly and yearly :
     $creator->add_RRA(-duration => "year") ;
     $creator->create(-filename => "df.rrd") ;
 
-=head1 SEE ALSO
-
-L<http://www.rrdtool.org/doc>, L<RRDTool::OO>
-
-
 =head1 AUTHOR
 
 Jacquelin Charbonnel, C<< <jacquelin.charbonnel at math.cnrs.fr> >>
@@ -614,7 +582,7 @@ L<http://annocpan.org/dist/RRDTool-Creator>
 
 =item * CPAN Ratings
 
-L<http://cpanratings.perl.org/d/RRDTool-Creator>
+L<http://cpanratings.perl.org/r/RRDTool-Creator>
 
 =item * RT: CPAN's request tracker
 
